@@ -17,6 +17,7 @@ pub const FLUENT_INDEX_SECTION: &str = "index";
 pub const FLUENT_LONG_SECTION: &str = "long";
 pub const FLUENT_SYMBOL_SECTION: &str = "symbol";
 pub const FLUENT_WEIGHT_SECTION: &str = "weight";
+pub const FLUENT_PRIME_SECTION: &str = "prime";
 
 pub trait Named {
     fn name(&self) -> &str;
@@ -81,8 +82,13 @@ pub trait Named {
     }
 
     /// Returns the default weight for a name. Weight is used to sort cards.
-    fn default_weight(&self) -> isize {
+    fn default_weight(&self) -> u32 {
         let weight = self.fluent_value(FLUENT_WEIGHT_SECTION, &US_ENGLISH);
         weight.parse().unwrap_or(0)
     }
+
+    fn default_prime(&self) -> u32 {
+        let prime = self.fluent_value(FLUENT_PRIME_SECTION, &US_ENGLISH);
+        prime.parse().unwrap_or(0)
+    }
 }
